# Chatbase Research

## Pricing

All prices are in USD.

- Standard:
	- 150/month -> 120/month for the year
	- 12k message credits
	- 10 AI actions/bot
	- 3 team members
	- 2 chat bots
- Pro:
	- 500/month -> 400/month for the year
	- 40k message credits
	- 15 AI Actions/bot
	- 5+ (25/month for each member after 5) team members
	- 3 chat bots
	- Advanced analytics

Add ons are probably the most important here:
- Auto recharge credits
	- Once a threshold is hit, add 1k credits for 14
- Extra credits
	- Manually add 1k credits for 12
- Extra chatbots 
	- 7/month
- Custom Domains
	- Custom domains for the embedded script, Iframe and chatbot link
	- 59/month
- Remove 'Powered by Chatbase'
	- Remove the branding from the iframe and widget
	- 39/month

- Assuming that we'd go for the pro plan, with a custom domain and removal of the branding, this would cost approx: 5976 a year
	- Realistically, we'd only need to get this if we wanted the advanced analytics since 40k messages might be overkill:
		- With an assumption that each user would ask 5 questions for a single conversation
		- 40k message credits a month -> 8k 'conversations' a month -> approx 266.6 conversations a day
- Assuming a more conservative approach with the standard plan, with the same custom domain and removal branding: 2616 a year
	- Might be a better option if we don't care about the advanced analytics
	- As I am not sure of the potential traffic and assuming that we use one of the 'cheaper' models (1 credit/message), with each user asking 5 questions that means that for 12k message credits we'd get about 2400 'conversations' a month or about 80 'conversations' a day.
- This can all be supplemented by the auto recharge add-on for a while until the system became tested enough so that we can expect a certain amount of traffic and then either switch plans or just use the extra credits add-on however many times we need.
- With the subscription, you get your set number of message credits each month. These expire and reset at the end of the month. The auto-renewing and additionally purchased credits are non-expiring and will roll over to the next month unlike the monthly subscription credits.

## Analytics

- Basic Analytics
	- Chats:
		- Total number of chats, messages and user interactions
		- Insight into user engagement and activity levels
	- Activity Tab:
		- Data per chat for users
		- Can track individual interactions and performance
	- Analytics Tab
		- Aggregates information into charts
	- Topics
		- Analytics on what topic was discussed are automatically collected
		- These topics can be added and updated manually
		- Freeing topics stops the AI agent from detecting topics automatically
	- Sentiment
		- AI agents detection of sentiment and emotion from users
- Advanced Analytics
	- Semantic
	- Topic

## Integrations

- Chatbase, before even looking at the API and documentation, has out of the box support for a number of integrations:
	- Bubble
	- Framer
	- Instagram
	- Messenger
	- Shopify
	- Slack
	- Sunshine
	- Webflow
	- Weebly
	- WhatsApp
	- Wix
	- WordPress
	- Zapier

## Legal

- In order to access the documentation on their trust centre, you need to request access to the documents. If/once approved, an email from Vanta will appear in your inbox. In the same pop-up it does state: 'If you have not signed an NDA, you will need to sign one before accessing the documents further'.
- Within the trust centre, it states that they are GDPR compliant and are working on becoming SOC2 and ISO 27001:2013 compliant also. This has been done in collaboration with Vanta
- Within the trust centre, it also lists of a number of 'Controls' that they have fulfilled under the following categories:
	- Infrastructure Security
	- Organisational Security
	- Product Security
	- Internal Security Procedures
	- Data and Privacy

### Privacy Statement

- 'With a few exceptions, this information is generally limited to:'
	- Name
	- Job title
	- Employer name
	- Work Address
	- Work Email
	- Work Phone number
- 'We do not sell personal information to anyone and only share it with third parties who are facilitating the delivery of our services'
- 'The personal information Chatbase collects from you is stored in one or more databases hosted by third parties located in the United States'
- 'These third parties do not use or have access to your personal information for any purpose other than cloud storage or retrieval'
- Third party sub processors:
	- Pinecone: Vector database hosting
	- OpenAI: AI services
	- Supabase: Cloud Provider
	- Vanta: Security/compliance monitoring
	- Vercel: Engineering
	- Anthropic: AI Services
	- Google Gemini: AI Services
	- Railway: Hosting Services
		- The following two are the only not listed as being in the US
	- Stripe: Payment Processor
	- Segment: Product analysis
- When adding a subprocess or, Chatbase will add them to the list and notify customers via notification that in 10 days they will be a active.
- 'We do not otherwise reveal your personal data to non-Chatbase persons or businesses for their independent use unless: ... providers who perform functions on our behalf; (5) to address emergencies or acts of God ...'
- 'Since it was founded, Chatbase has received zero government requests for information'
- Use of Google Workspaces APIs is done to provide certain functionalities within their service, however, they 'explicitly affirm' that any data obtained through the Google Workspace APIs is not used to develop, improve or train generalised AI or ML models.
- They have a number of data protection mechanisms:
	- Encryption - both at rest and in transit using 'industry-standard algorithms'
	- Access control - User roles and permissions are in place so that only authorised personnel can access sensitive data
	- Rate Limiting - Can customise the rate limiting to protect against abuse and spam
	- Domain allow list - Can control which domains the chatbot(s) can be embedded on
	- Infrastructure security - Database and application run on AWS infrastructure (us-east-1) managed by Supabase, Vercel and Pinecone
	- Compliance - DPR compliant and in SOC 2 compliance is in progress
	- No AI training - Data collected is not used in the training of AI, they use RAG (Retrieval-Augmented Generation) to generate responses
- 'We do not knowingly attempt to solicit or receive information from children.'

### Terms of Service

- 'Chatbase may also suspend or terminate API access at any time'
- 'Fees are non-refundable'
- 'Customers have the option not to renew their subscription if they disagree with any revised fees.'

## AI Actions

- AI actions are a set of functions or tasks that the AI agent can trigger during a conversation.
- These can range from efficiency improvements, enhancing the conversation, gathering information, providing insights and integrations with other systems
- There are a number of built in actions along with the option for a custom action:
	- Button
		- The button action specifies that a button can be provided for the user (that contains a specific URL) when the instructions are followed:
			- E.g. 'Provide the user a button when they ask about TaskFlo policies'
	- Search
		- The web search action allows the AI agent to browse the web for information and feed the information back to the AI agent
		- E.g.'Use when the user asks for a topic or question which you don't know the answer to, or topics that you have outdated information about. Call this tool to search the web for information and reply with the search results. Always show images'
		- There is also the option to include images, along with allowing the search to only happen on specific domains
	- Slack
		- Can provide a Slack Workspace and instructions that can then integrate with Slack
		- E.g. 'Call this tool to send a message in Slack to the channel named: <CHANNEL_NAME> whenever the user mentions any of the following topics: <TOPICS>'
		- The items in brackets would be filled in.
	- Cal.com and Calendly
		- These actions are both similar enough that they can be described together
		- Main difference is that for Cal.com, you provide an event URL whereas Calendly requires integration with you Calendly account
		- Both of these actions allow for the user to make bookings through the AI agent, taking into account availability:
			- E.g. 'Call this action when the user mentions that they want to book an appointment. If the user specifies a date only without time, set the time window without confirming with the user to that same day from 12AM to 11:59PM, but if the user does not specify a data nor a time, set the time window, without asking or confirming, to be from today at 12AM to 1 week from today at 12AM. Check if the user attempted to book an appointment or not from the tool resuk. This is not a certainty that the user completed the appointment booking. If the user asked about whether they booked an appointment or not, asnwer that the user attempted to book the appointment or did not book an appointment. The window can only be 1 week long, if the userspecified a lomnger period, use the same starting time, and the ending time should be 1 week later, responding to the user that the window cannot be longer than 1 week.'
	- Custom Action
		- Custom actions are the most versatile actions that the AI agent has access to.
		- You're able to setup an action that can:
			- Collect data inputs from the user via a list
				- E.g. Name: city, type: text, description: city that you want to know its weather
			- Make an API request
				- This can be given variables from the data input mentioned above
				- Can also send specific parameters, headers and body
			- Cusstom Data access
				- The data that comes back from the API can be limited to either: 
					- Full data access (all available information from the response, ensuring comprehensive responses)
					- Limited data access (limit the information, providing more controlled and specific replies while protecting sensitive data)
	- Collect Leads
		- This action can be used to send the user a form in the chat window
		- E.g. 'Use at the start of the conversation to collect the user information', along with providing what a good response looks like and success/dismiss messages can be
		- It appears that the three available form fields are name, email and phone number.

## Contact Information

- Chatbase.co Inc. @ 4700 Keele Street, 215 Bergeron Center, Toronto, ON, Canada, M3J 1P3
- privacy@chatbase.co
- support@chatbase.co
- Can also send in tickets to the customer support team once logged in with an account
- Could not find any information relating to their response times.

## Misc

- When reading through the site, I'd asked the Chatbot 'Where on this page does it talk about cookies and tracking tech?', this is whilst I was on their [legal/privacy](https://www.chatbase.co/legal/privacy) page. The chat bot responded that they're not able to view or access the contents of the page that I'm currently on, but did tell me where to find the information correctly
- Chatbase is a product that was initially developed in Area 120, Google's in-house incubator; eventually graduating to Google Cloud
- Document mapping website URL to page names is possible, providing the chatbot a source of [URL]: [name of page] means that it'll be able to link those instead of creating fake links.

## Sources

- https://techcrunch.com/2017/11/16/googles-chatbot-analytics-platform-chatbase-launches-to-public/
- https://www.chatbase.co/legal/privacy
- https://www.chatbase.co/docs/user-guides/quick-start/introduction
- https://trust.chatbase.co/
- https://www.chatbase.co/legal/cookie-policy
- https://www.chatbase.co/legal/dpa
- https://www.chatbase.co/legal/terms
- https://www.chatbase.co/security
- https://www.vanta.com/
- https://trust.chatbase.co/subprocessors
